@@ -73,7 +73,9 @@ def setup_instance_from_store(store: InstanceSettingsStore) -> InstanceSettings:
     settings = InstanceSettings()
     settings.storage_dir = setup_storage_dir(store.storage_dir)
     settings._dbconfig = store.dbconfig
-    settings.schema_modules = store.schema_modules
+    settings.schema_modules = (
+        store.schema_modules if store.schema_modules != "null" else None
+    )
     settings.storage_region = store.storage_region
     return settings
 
